<?php

/*
Plugin Name: Allow RDF Uploads
Plugin URI: http://simonwheatley.co.uk/wordpress/ardfu
Description: Allow RDF files to be uploaded to WordPress
Version: 0.1
Author: Simon Wheatley
Author URI: http://simonwheatley.co.uk//wordpress/
*/
 
/*  Copyright 2011 Simon Wheatley

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

/**
* Hooks the upload_mimes to add RDF as an allowed mime type
*/
class AllowRDFUploads {

	/**
	 * To store the mime types we want to add
	 *
	 * @var array
	 **/
	protected $additional_mimes;
	
	/**
	 * Constructor
	 *
	 * @return void
	 * @author Simon Wheatley
	 **/
	function __construct() {
		$this->additional_mimes = array(
			array()
		);
		add_filter( 'upload_mimes', array( $this, 'upload_mimes' ) );
	}

	/**
	 * Hooks the WP upload_mimes filter to allow RDF to be uploaded.
	 *
	 * @param array $mimes The currently allowed mimetypes as an array, e.g.  
	 * @return The allowed mimetypes
	 * @author Simon Wheatley
	 **/
	public function upload_mimes( $mimes ) {
		$mimes = array_merge( $mimes, array( 'rdf' => 'application/rdf+xml' ) );
		return $mimes;
	}
}

$allow_rdf_uploads = new AllowRDFUploads;

?>